@@ -7,7 +7,6 @@ extern char **seq_g;
 extern char **res_g;
 static int subalignment;
 static int subalignmentoffset;
-static int specifictarget;
 
 static int intop;
 static int intree;
@@ -116,6 +115,11 @@ void arguments( int argc, char *argv[] )
 					fprintf( stderr, "inputfile = %s\n", inputfile );
 					--argc;
 					goto nextoption;
+				case 'K':
+					nadd = myatoi( *++argv );
+					fprintf( stderr, "nadd = %d\n", niter );
+					--argc;
+					goto nextoption;
 				case 'I':
 					niter = myatoi( *++argv );
 					fprintf( stderr, "niter = %d\n", niter );
@@ -179,6 +183,7 @@ void arguments( int argc, char *argv[] )
 					--argc; 
 					goto nextoption;
 				case 'l':
+					bunkatsu = 0;
 					fastathreshold = atof( *++argv );
 					constraint = 2;
 					--argc;
@@ -440,6 +445,7 @@ int main( int argc, char *argv[] )
 	int alignmentlength;
 	int **skipthisbranch;
 	int foundthebranch;
+	int *reftable;
 	int nsubalignments, maxmem;
 	int **subtable;
 	int *insubtable;
@@ -477,9 +483,21 @@ int main( int argc, char *argv[] )
 
 	if( njob < 2 ) 
 	{
-		fprintf( stderr, "At least 2 sequences should be input!\n"
-						 "Only %d sequence found.\n", njob ); 
-		exit( 1 );
+		seq = AllocateCharMtx( 2, nlenmax*1+1 );
+    	name = AllocateCharMtx( 2, B+1 );
+//	    nlen = AllocateIntVec( 2 ); 
+		readData_pointer( infp, name, nlen, seq );
+		fclose( infp );
+		initFiles();
+		gappick0( seq[1], seq[0] );
+//		writeData_pointer( prep_g, njob, name, nlen, seq+1 );
+		writeData_pointer( prep_g, njob, name, nlen, seq+1 );
+		reporterr( "Warning: Only %d sequence found.\n", njob ); 
+		FreeCharMtx( seq );
+		FreeCharMtx( name );
+//		free( nlen );
+		closeFiles();
+		exit( 0 );
 	}
 
 
@@ -763,6 +781,7 @@ exit( 1 );
 	printf( "utree = %d\n", utree );
 #endif
 
+
 	if( autosubalignment > 0.0 && subalignment == 0 )
 	{
 //		reporterr( "Computing skipthisbranch..\n" );
@@ -869,6 +888,36 @@ exit( 1 );
 	}
 
 
+//--------------- nadd kokokara ----
+	if( nadd > 0 )
+	{
+		reftable = calloc( sizeof( int ), njob );
+		for( j=0; j<njob-nadd; j++ ) reftable[j] = j;
+		reftable[njob-nadd] = -1;
+		for( j=0; j<njob-1; j++ ) 
+		{
+#if 0
+				int k;
+				reporterr( "####  STEP%d\n", j );
+				for( k=0; topol[j][0][k]!=-1; k++ ) reporterr( "%3d ", topol[j][0][k] );
+				reporterr( "\n" );
+				if( overlapmember( topol[j][0], reftable ) && !samemember( topol[j][0], reftable ) ) reporterr( "Skip\n" );
+				else reporterr( "Not skip\n" );
+				for( k=0; topol[j][1][k]!=-1; k++ ) reporterr( "%3d ", topol[j][1][k] );
+				reporterr( "\n" );
+				if( overlapmember( topol[j][1], reftable ) && !samemember( topol[j][1], reftable ) ) reporterr( "Skip\n" );
+				else reporterr( "Not skip\n" );
+#endif
+				//if( overlapmember( topol[j][0], reftable ) ) skipthisbranch[j][0] = 1;
+				//if( overlapmember( topol[j][1], reftable ) ) skipthisbranch[j][1] = 1;
+//				( ( reference, fragment1 ), fragment2 ) no, reference ni itaru eda ha skip shinai.
+				if( overlapmember( topol[j][0], reftable ) && !samemember( topol[j][0], reftable ) ) skipthisbranch[j][0] = 1;
+				if( overlapmember( topol[j][1], reftable ) && !samemember( topol[j][1], reftable ) ) skipthisbranch[j][1] = 1;
+
+		}
+		free( reftable );
+	}
+//--------------- nadd kokomade ----
 //--------------- kokokara ----
 	if( subalignment || autosubalignment )
 	{
