@@ -1,5 +1,8 @@
 #define USE_XCED 0
 
+#define _SVID_SOURCE
+#define _BSD_SOURCE
+
 #if USE_XCED
 #include "config.h"
 #include "share.h"
@@ -17,16 +20,23 @@
 #include <ctype.h>
 #include "mtxutl.h"
 //#include <double.h>
+#include <limits.h>
 #include <stdarg.h>
 #ifdef enablemultithread
 #include <pthread.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #endif
 #ifndef mingw
 #include <sys/resource.h> // for setstacksize, 2016/Jun
+#include <sys/shm.h> // shared memory
+#include <sys/mman.h> // shm_open
 #endif
 
-#define VERSION "7.310"
-#define SHOWVERSION reporterr( "%s (%s) Version " VERSION " alg=%c, model=%s, amax=%3.1f\n%d thread(s)\n\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
+
+
+#define VERSION "7.402"
+#define SHOWVERSION reporterr( "%s (%s) Version " VERSION "\nalg=%c, model=%s, amax=%3.1f\n%d thread(s)\n\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
 #define FFT_WINSIZE_P   20
@@ -295,6 +305,22 @@ typedef struct _Addtree
 	double dist2;
 } Addtree;
 
+typedef struct _lennum
+{
+	int len;
+	int num;
+} Lennum;
+
+typedef struct _pairnum
+{
+	unsigned long long npairs;
+	int num;
+	int n0;
+	int n1;
+} Pairnum;
+
+
+
 #include "fft.h"
 #include "dp.h"
 #include "functions.h"
@@ -310,6 +336,8 @@ extern TLS int commonAlloc2;
 extern TLS int **commonIP;
 extern TLS int **commonJP;
 extern int nthread;
+extern int nthreadreadlh;
+extern int nthreadpair;
 extern int randomseed;
 extern int parallelizationstrategy;
 #define BESTFIRST 0
@@ -336,4 +364,14 @@ extern int gmsg;
 
 extern double sueff_global;
 extern double lenfaca, lenfacb, lenfacc, lenfacd;
-int maxl, tsize;
+extern int maxl, tsize;
+
+
+/* for --large  */
+extern int compacttree;
+extern int lhlimit;
+extern int specifictarget;
+#define HAT3NODEBLOCK 500
+extern int nadd;
+extern int usenaivescoreinsteadofalignmentscore;
+#define MYBUFSIZE 1000 * 1000 * 100 // 100MB
